<?php
declare(strict_types = 1);

namespace App\Http\Resources\Outpatient\Record;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class RecordDetailsResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request = null): array
    {
        $info = [
            'date' => date('Y-m-d H:i:s', strtotime($this->resource['JSRQ'])),
            'receipt_id' => $this->resource['TREAID'],
            'receipt_no' => $this->resource['HOSTRANNO'],
            'total_fee' => (float) $this->resource['COSTS'],
            'self_fee' => (float) $this->resource['GRZF'] ?? 0,
            'reduce_fee' => (float) $this->resource['JJZF'] ?? 0,
            'exec_address' => $this->resource['PHYADDRESS'] ?: '',
            'dept_name' => $this->resource['DEPNAME'],
            'doctor_name' => $this->resource['DOCTNAME'],
            'clinic_diagnosis' => $this->resource['CYZD'],
            'charge_user' => $this->resource['CZGH'],
        ];

        $this->resource['RECORD'] = xmlArrayToListByKey($this->resource['RECORD'], 'ITEMREC');

        foreach ($this->resource['RECORD']['ITEMREC'] as $v) {
            $info['item_lists'][] = [
                'visit_date' => $v['VISITDATE'],
                'category_name' => $v['CLASSNAME'],
                'item_name' => $v['ITEMNAME'],
                'spec' => $v['ITEMSPEC'],
                'unit' => $v['UNITS'],
                'quantity' => (int) $v['AMOUNT'],
                'price' => (float) $v['PRICE'],
                'total_price' => (float) $v['COSTS'],

                // 冗余字段
                'package_name' => $v['ZTMC'] ?: '',
                'dose_per_administration' => $v['YCJL'] ?: '',
                'dose_unit' => $v['JLDW'] ?: '',
                'days_of_use' => $v['YYTS'] ?: '',
                'frequency_per_day' => $v['MRCS'] ?: '',
                'dosage_schedule_name' => $v['PCMC'] ?: '',
                'medical_insurance_code' => $v['YPBM'] ?: '',
                'drug_registration_code' => $v['YJBM'] ?: '',
                'medical_insurance_category' => $v['YBFL'] ?: '',
                'employee_name' => $v['YGXM'] ?:'',
            ];
        }

        return $info;
    }
}
