<?php

namespace App\Http\Resources\Registration\Schedule;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Redis;

class DoctorListsResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request = null): array
    {
        $doctor_lists = $this->getDoctorLists();
        $specialty = collect($doctor_lists)->pluck('specialty', 'doctor_id');
        $sort = collect($doctor_lists)->pluck('sort', 'doctor_id');

        $lists = [];
        foreach ($this->resource['response'] as $k=>$v) {
            $lists[$k] = [
                'doctor_id' => $v['doctId'],
                'doctor_name' => $v['doctName'],
                'doctor_title' => $v['docTitle'],
                'doctor_intro' => $specialty[$v['doctId']] ?? ($v['depLocation'] ?: '暂无介绍'),
                'is_doctor' => (int) $v['isksDoc'],
            ];

            foreach ($v['doctotVisitInfoList'] as $k2 => $v2) {
                $lists[$k]['schedule_lists'][$k2] = [
                    'reg_id' => $v2['regId'],
                    'date' => $v2['visitDate'],
                    'rank_id' => $v2['rankId'],
                    'rank_name' => $v2['rankName'],
                    'start_time' => $v2['startTime'],
                    'end_time' => $v2['endTime'],
                    'fee' => (float) $v2['fee'],
                    'fee_code' => $v2['feeCode'],
                    'reg_count' => (int) $v2['regCount'],
                    'no_visit_count' => (int) $v2['noVisits'],
                ];
            }
        }

        // 根据医生的 sort 字段对 $lists 进行排序
        usort($lists, function ($a, $b) use ($sort) {
            $sort_a = $sort[$a['doctor_id']] ?? 0;
            $sort_b = $sort[$b['doctor_id']] ?? 0;
            return $sort_b <=> $sort_a; // 倒序排序
        });

        return $lists;
    }

    /**
     * 获取医生列表
     * @return array
     */
    public function getDoctorLists(): array
    {
        if (Redis::exists('doctor.lists')) {
            $doctor_lists = Redis::get('doctor.lists');
            $doctor_lists = json_decode($doctor_lists, true);
        } else {
            $db = DB::connection('mysql_admin')->table('doctors');
            $doctor_lists = $db
                ->where('is_enable', 1)
                ->orderBy('sort', 'DESC')
                ->orderBy('id', 'ASC')
                ->get();

            Redis::setex('doctor.lists', 4 * 3600, json_encode($doctor_lists, JSON_UNESCAPED_UNICODE));
        }

        return $doctor_lists;
    }
}
