<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class () extends Migration {

    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('registration_records', static function (Blueprint $table) {
            $table->id();
            $table->integer('relate_order_id')->index()->comment('关联订单表ID');
            $table->integer('relate_patient_id')->index()->comment('关联患者表ID');
            $table->string('reg_id', 20)->index()->comment('挂号流水号');
            $table->string('dept_id', 10)->comment('科室ID');
            $table->string('dept_name', 20)->comment('科室名称');
            $table->string('dept_location', 50)->comment('科室地址');
            $table->string('doctor_id', 20)->comment('医生ID');
            $table->string('doctor_name', 20)->comment('医生名称');
            $table->string('visit_date', 10)->index()->comment('就诊日期');
            $table->string('begin_time', 5)->index()->comment('开始时间');
            $table->string('end_time', 5)->comment('结束时间');
            $table->tinyInteger('lock_status')->index()->comment('锁号状态 0 系统不支持锁号 1 已锁号 2 已解锁');
            $table->timestamp('lock_at')->nullable()->comment('锁号时间');
            $table->timestamp('unlock_at')->nullable()->comment('解锁时间');
            $table->text('extra_info')->comment('额外的挂号信息');
            $table->tinyInteger('reminder_sent')->default(0)->comment('是否已推送就诊提醒');
            $table->timestamps();
            $table->engine = 'InnoDB';
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('registration_records');
    }
};
